@@ -34,7 +34,28 @@ The packages exported are:
   monitor_utils  -- A collection of abstractions that can be used to implement monitors.
 """
 
-__author__ = 'Steven Czerwinski <czerwin@scalyr.com>'
+# [start of 2->TODO]
+# all source code files should have unicode literals by using "from __future__ import unicode_literals"
+# By using unicode literals, we will have to explicitly specify literals and variables with binary data,
+# By the way we have to use io.StringIO and io BytesIO
+# instead of sStringIO.StringIO by the same reason(python3 does not have such things)
+# As we are not able to use something different in python3,
+# I think we should use the same things in python2, to achieve maximal identity of the behaviour.
+# [end of 2->TOD0]
+
+from __future__ import absolute_import
+
+__author__ = "Steven Czerwinski <czerwin@scalyr.com>"
+
+# [start of 2->TODO]
+#  "Modernize" tool added "six" library almost everywhere.
+#  So we need to add third_party libraries in PYTHONPATH before "six" will be imported in any further file.
+
+from scalyr_agent.__scalyr__ import scalyr_init
+
+scalyr_init()
+
+# [end of 2->TODO]
 
 from scalyr_agent.scalyr_monitor import ScalyrMonitor
 from scalyr_agent.scalyr_monitor import BadMonitorConfiguration
@@ -51,11 +72,30 @@ from scalyr_agent.scalyr_logging import getLogger
 from scalyr_agent.scalyr_logging import AgentLogger
 from scalyr_agent.scalyr_logging import DEBUG_LEVEL_0, DEBUG_LEVEL_1, DEBUG_LEVEL_2
 from scalyr_agent.scalyr_logging import DEBUG_LEVEL_3, DEBUG_LEVEL_4, DEBUG_LEVEL_5
+from scalyr_agent.scalyr_logging import AutoFlushingRotatingFileHandler
 
-import json_lib
-import monitor_utils
+from . import json_lib
+from . import monitor_utils
 
-__all__ = ['ScalyrMonitor', 'MonitorConfig', 'BadMonitorConfiguration', 'UnsupportedSystem', 'getLogger', 'AgentLogger',
-           'StoppableThread', 'RunState', 'DEBUG_LEVEL_0', 'DEBUG_LEVEL_1', 'DEBUG_LEVEL_2', 'DEBUG_LEVEL_3',
-           'DEBUG_LEVEL_4', 'DEBUG_LEVEL_5', 'json_lib', 'monitor_utils', 'define_metric', 'define_config_option',
-           'define_log_field']
\ No newline at end of file
+__all__ = [
+    "ScalyrMonitor",
+    "MonitorConfig",
+    "BadMonitorConfiguration",
+    "UnsupportedSystem",
+    "getLogger",
+    "AgentLogger",
+    "StoppableThread",
+    "RunState",
+    "DEBUG_LEVEL_0",
+    "DEBUG_LEVEL_1",
+    "DEBUG_LEVEL_2",
+    "DEBUG_LEVEL_3",
+    "DEBUG_LEVEL_4",
+    "DEBUG_LEVEL_5",
+    "json_lib",
+    "monitor_utils",
+    "define_metric",
+    "define_config_option",
+    "define_log_field",
+    "AutoFlushingRotatingFileHandler",
+]
