@@ -28,7 +28,7 @@ from __future__ import absolute_import
 
 __author__ = "czerwin@scalyr.com"
 
-if False:
+if False:  # NOSONAR
     # NOTE: This is a workaround for old Python versions where typing module is not available
     # We should eventually improve that once we start producing distributions with Python
     # interpreter and dependencies bundled in.
